@@ -12,7 +12,12 @@ multiple-file aspects.
 
     use MARC::Batch;
 
-    my $batch = new MARC::Batch-new( 'USMARC', @files );
+    # If you have weird control fields...
+    use MARC::Field;
+    MARC::Field->allow_controlfield_tags('FMT', 'LDX');    
+    
+
+    my $batch = MARC::Batch->new( 'USMARC', @files );
     while ( my $marc = $batch->next ) {
         print $marc->subfield(245,"a"), "\n";
     }
@@ -111,6 +116,9 @@ sub next {
         my $rec = $self->{file}->next( $filter );
 
         # collect warnings from MARC::File::* object
+        # we use the warnings() method here since MARC::Batch
+        # hides access to MARC::File objects, and we don't
+        # need to preserve the warnings buffer.
         my @warnings = $self->{file}->warnings();
         if ( @warnings ) {
             $self->warnings( @warnings );
@@ -120,7 +128,12 @@ sub next {
         if ($rec) {
 
             # collect warnings from the MARC::Record object
-            my @warnings = $rec->warnings();
+            # IMPORTANT: here we don't use warnings() but dig
+            # into the the object to get at the warnings without
+            # erasing the buffer. This is so a user can call 
+            # warnings() on the MARC::Record object and get back
+            # warnings for that specific record.
+            my @warnings = @{ $rec->{_warnings} };
 
             if (@warnings) {
                 $self->warnings( @warnings );
